Testing your source code - Betty documentation

Hide navigation sidebar
Hide table of contents sidebar
Skip to content
Back to top
View this page
Toggle table of contents sidebar

# Testing your source code

If your software project uses Betty, you may be able to use some of the many test utilities Betty provides for your benefit:

- Pytest `fixtures`

- Base classes to to help you get started writing tests for your implementations of Betty’s abstract classes. These have class names ending in `TestBase`.

- Dummy implementations of abstract classes. These have class names starting with `Dummy`.

- `Assertion error handling`

- Testing if your `*.pot` translations file is up to date with `betty.test_utils.locale.PotFileTestBase`

All test utilities can be found in `betty.test_utils`.